@@ -1,6 +1,6 @@
 /* Various routines to perform simple actions.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -120,7 +120,7 @@ void clear_channel(Channel *chan, int what, const void *param)
     if (what & CLEAR_BANS)
 	clear_bans(sender, chan, (User *)param);
     if (what & CLEAR_UMODES)
-	clear_umodes(sender, chan, (int32)param);
+	clear_umodes(sender, chan, (int32)(long)param);
     set_cmode(NULL, chan);	/* Flush modes out */
 }
 
