@@ -1,6 +1,6 @@
 /* Configuration file handling.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -256,7 +256,7 @@ static int parse_config_line(const char *filename, int linenum, char *buf,
 		    break;
 		}
 #if SIZEOF_LONG > 4
-		if (longval > 0xFFFFFFFFL) {
+		if (ulongval > 0xFFFFFFFFL) {
 		    config_error(filename, linenum,
 				 "%s: Value out of range for parameter %d",
 				 d->name, optind);
