@@ -366,7 +366,7 @@
 #define CHAN_SET_MLOCK_MODE_REG_BAD      365
 #define CHAN_SET_MLOCK_LINK_BAD          366
 #define CHAN_SET_MLOCK_LINK_SAME         367
-#define CHAN_SET_MLOCK_LINK_NO_LIMIT     368
+#define CHAN_SET_MLOCK_REQUIRES          368
 #define CHAN_SET_MLOCK_BAD_PARAM         369
 #define CHAN_SET_MLOCK_UNKNOWN_CHAR      370
 #define CHAN_SET_MLOCK_CANNOT_LOCK       371
