@@ -1,6 +1,6 @@
 /* Logging routines.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -97,6 +97,23 @@ static void check_log_rotate(void)
 
 static void vlogprintf(const char *fmt, va_list args)
 {
+    if (nofork) {
+#ifdef NO_VA_COPY
+	static int warned = 0;
+	if (!warned) {
+	    fprintf(stderr,
+"*** Cannot write log messages to stderr because Services was compiled with\n"
+"    an obsolete compiler.  Please upgrade your compiler and recompile\n"
+"    Services.\n"
+	    );
+	    warned = 1;
+	}
+#else
+	va_list argscopy;
+	va_copy(argscopy, args);
+	vfprintf(stderr, fmt, argscopy);
+#endif
+    }
     if (logfile) {
 	check_log_rotate();
 	vfprintf(logfile, fmt, args);
@@ -119,8 +136,6 @@ static void vlogprintf(const char *fmt, va_list args)
 	    logmemptr += len;
 	}
     }
-    if (nofork)
-	vfprintf(stderr, fmt, args);
 }
 
 static void logprintf(const char *fmt, ...) FORMAT(printf,1,2);
