@@ -1,6 +1,6 @@
 /* Module support.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -335,12 +335,18 @@ static Module *internal_load_module(const char *modulename)
     }
     module->name = sstrdup(name);
 
-    verptr = get_module_symbol(module, "module_version");  /* as above */
+    verptr = get_module_symbol(module, "module_version");
+    /* With static modules, module_version is known to be defined at
+     * compile time; furthermore, some linkers (hey there, MacOS) merge
+     * common constants into a single value, so all these would end up
+     * pointing to the same value. */
+#if !defined(STATIC_MODULES)
     if (verptr) {
 	LIST_SEARCH_SCALAR(modulelist, module_version_ptr, verptr, mptr);
 	if (mptr)
 	    verptr = NULL;
     }
+#endif
     if (!verptr) {
 	log("modules: Unable to load module `%s': No `module_version'"
 	    " symbol found", modulename);
