@@ -1,6 +1,6 @@
 /* Main ChanServ module.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -323,6 +323,21 @@ static int do_channel_join(Channel *c, struct c_userlist *u)
 
 /*************************************************************************/
 
+/* Callback for users leaving channels.  Update the channel's last used
+ * time if the user was an auto-op user.
+ */
+
+static int do_channel_part(Channel *c, User *u, const char *reason)
+{
+    if (c->ci && check_access(u, c->ci, CA_AUTOOP)) {
+	c->ci->last_used = time(NULL);
+	put_channelinfo(c->ci);
+    }
+    return 0;
+}
+
+/*************************************************************************/
+
 /* Callback for channels being deleted. */
 
 static int do_channel_delete(Channel *c)
@@ -572,13 +587,16 @@ static void do_help(User *u)
 	notice_help(s_ChanServ, u, CHAN_HELP_REGISTER);
 	notice_help(s_ChanServ, u, CHAN_HELP_REGISTER_ADMINONLY);
     } else if (stricmp(cmd, "LIST") == 0) {
-	notice_help(s_ChanServ, u, CHAN_HELP_LIST);
+	if (is_oper(u))
+	    notice_help(s_ChanServ, u, CHAN_OPER_HELP_LIST);
+	else
+	    notice_help(s_ChanServ, u, CHAN_HELP_LIST);
 	if (CSListOpersOnly)
 	    notice_help(s_ChanServ, u, CHAN_HELP_LIST_OPERSONLY);
     } else if (stricmp(cmd, "KICK") == 0) {
 	cmdrec = lookup_cmd(module, cmd);
 	notice_help(s_ChanServ, u, CHAN_HELP_KICK,
-	     getstring_cmdacc(u->ngi, cmdrec ? (int)cmdrec->help_param1 : -1));
+	     getstring_cmdacc(u->ngi, cmdrec ? (int)(long)cmdrec->help_param1 : -1));
 	if (protocol_features & PF_CHANPROT)
 	    notice_help(s_ChanServ, u, CHAN_HELP_KICK_PROTECTED);
     } else if (stricmp(cmd, "CLEAR") == 0) {
@@ -592,7 +610,7 @@ static void do_help(User *u)
 	    notice_help(s_ChanServ, u, CHAN_HELP_CLEAR_HALFOPS);
 	cmdrec = lookup_cmd(module, cmd);
 	notice_help(s_ChanServ, u, CHAN_HELP_CLEAR_END,
-	     getstring_cmdacc(u->ngi, cmdrec ? (int)cmdrec->help_param1 : -1));
+	     getstring_cmdacc(u->ngi, cmdrec ? (int)(long)cmdrec->help_param1 : -1));
     } else if ((stricmp(cmd, "AKICK") == 0
 		|| stricmp(cmd, "OP") == 0
 		|| stricmp(cmd, "DEOP") == 0
@@ -611,7 +629,7 @@ static void do_help(User *u)
 	    && (cmdrec = lookup_cmd(module, cmd)) != NULL
     ) {
 	notice_help(s_ChanServ, u, cmdrec->helpmsg_all,
-		    getstring_cmdacc(u->ngi, (int)cmdrec->help_param1));
+		    getstring_cmdacc(u->ngi, (int)(long)cmdrec->help_param1));
     } else {
 	help_cmd(s_ChanServ, u, module, cmd);
     }
@@ -867,6 +885,21 @@ static void do_info(User *u)
 	notice_lang(s_ChanServ, u, INTERNAL_ERROR);
     } else {
 
+	/* Update last used time if the channel is currently in use. */
+	if (ci->c) {
+	    struct c_userlist *cu;
+	    LIST_FOREACH (cu, ci->c->users) {
+		if (check_access(cu->user, ci, CA_AUTOOP)) {
+		    if (debug >= 2)
+			module_log("debug: updating last used time for %s"
+				   " (INFO)", ci->name);
+		    ci->last_used = time(NULL);
+		    put_channelinfo(ci);
+		    break;
+		}
+	    }
+	}
+
         /* Only show all the channel's settings to sadmins and founders. */
 	can_show_all = (is_founder(u, ci) || is_servadmin);
 
@@ -1540,9 +1573,12 @@ static void do_forbid(User *u)
 	ci->time_registered = time(NULL);
 	notice_lang(s_ChanServ, u, CHAN_FORBID_SUCCEEDED, chan);
 	c = get_channel(chan);
-	if (c)
+	if (c) {
+	    ci->c = c;  /* for completeness */
+	    c->ci = ci;
 	    clear_channel(c, CLEAR_USERS,
 			  "Use of this channel has been forbidden");
+	}
     } else {
 	module_log("Valid FORBID for %s by %s!%s@%s failed",
 		   ci->name, u->nick, u->username, u->host);
@@ -1863,6 +1899,7 @@ int init_module(Module *module_)
      || !add_callback(NULL, "channel create", do_channel_create)
      || !add_callback(NULL, "channel JOIN check", do_channel_join_check)
      || !add_callback(NULL, "channel JOIN", do_channel_join)
+     || !add_callback(NULL, "channel PART", do_channel_part)
      || !add_callback(NULL, "channel delete", do_channel_delete)
      || !add_callback(NULL, "channel mode change", do_channel_mode_change)
      || !add_callback(NULL, "channel umode change", do_channel_umode_change)
@@ -1924,6 +1961,7 @@ int exit_module(int shutdown_unused)
     remove_callback(NULL, "channel umode change", do_channel_umode_change);
     remove_callback(NULL, "channel mode change", do_channel_mode_change);
     remove_callback(NULL, "channel delete", do_channel_delete);
+    remove_callback(NULL, "channel PART", do_channel_part);
     remove_callback(NULL, "channel JOIN", do_channel_join);
     remove_callback(NULL, "channel JOIN check", do_channel_join_check);
     remove_callback(NULL, "channel create", do_channel_create);
