@@ -1,6 +1,6 @@
 /* SET command handling.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -278,7 +278,7 @@ static void do_set_password(User *u, ChannelInfo *ci, char *param)
     else
 	notice_lang(s_ChanServ, u, CHAN_PASSWORD_CHANGED, ci->name);
     memset(param, 0, len);
-    if (get_access(u, ci) < ACCLEV_FOUNDER) {
+    if (!is_founder(u, ci)) {
 	module_log("%s!%s@%s set password as Services admin for %s",
 		   u->nick, u->username, u->host, ci->name);
 	if (WallSetpass)
