@@ -1,7 +1,7 @@
 /* Routines to load/save Services databases in the (hopefully one day
  * obsolete) format used by version 4.x.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -1610,7 +1610,7 @@ NewsItem *add_news(NewsItem *newsitem)
 	fatal("add_news(): too many news items!");
     ARRAY_EXTEND(newslist);
     memcpy(&newslist[newslist_count-1], newsitem, sizeof(NewsItem));
-    newslist[newslist_count-1].next = (NewsItem *)(newslist_count-1); /*index*/
+    newslist[newslist_count-1].next = (NewsItem *)(long)(newslist_count-1); /*index*/
     free(newsitem);
     return &newslist[newslist_count-1];
 }
@@ -1619,7 +1619,7 @@ NewsItem *add_news(NewsItem *newsitem)
 
 void del_news(NewsItem *newsitem)
 {
-    int num = (int)(newsitem->next);
+    int num = (int)(long)(newsitem->next);
     if (num < 0 || num >= newslist_count) {
 	module_log("del_news(): invalid index %d in news item at %p",
 		   num, newsitem);
@@ -1630,7 +1630,7 @@ void del_news(NewsItem *newsitem)
     if (num < newslist_iterator)
 	newslist_iterator--;
     while (num < newslist_count) {
-	newslist[num].next = (NewsItem *)num;
+	newslist[num].next = (NewsItem *)(long)num;
 	num++;
     }
 }
@@ -1699,7 +1699,7 @@ int open_news_db(const char *dbname)
     for (i = 0; i < tmp16; i++) {
 	int32 tmp32;
 	if (i < newslist_count) {  /* watch out for stored count > MAX_NEWS */
-	    newslist[i].next = (NewsItem *) i;
+	    newslist[i].next = (NewsItem *) (long)i;
 	    SAFE(read_int16(&newslist[i].type, f));
 	    SAFE(read_int32(&newslist[i].num, f));
 	    SAFE(read_string(&newslist[i].text, f));
@@ -1791,7 +1791,7 @@ MaskData *add_maskdata(uint8 type, MaskData *data)
 	fatal("add_maskdata(): too many items for type %u", type);
     ARRAY2_EXTEND(masklist[type], masklist_count[type]);
     memcpy(&masklist[type][num], data, sizeof(*data));
-    masklist[type][num].next = (MaskData *)num;  /* use as index */
+    masklist[type][num].next = (MaskData *)(long)num;  /* use as index */
     free(data);
     return &masklist[type][num];
 }
@@ -1800,7 +1800,7 @@ MaskData *add_maskdata(uint8 type, MaskData *data)
 
 void del_maskdata(uint8 type, MaskData *data)
 {
-    int num = (int)(data->next);
+    int num = (int)(long)(data->next);
     if (num < 0 || num >= masklist_count[type]) {
 	module_log("del_maskdata(): invalid index %d for type %u at %p",
 		   num, type, data);
@@ -1812,7 +1812,7 @@ void del_maskdata(uint8 type, MaskData *data)
     if (num < masklist_iterator[type])
 	masklist_iterator[type]--;
     while (num < masklist_count[type]) {
-	masklist[type][num].next = (MaskData *)num;
+	masklist[type][num].next = (MaskData *)(long)num;
 	num++;
     }
 }
@@ -1901,7 +1901,7 @@ static int read_maskdata(uint8 type, const char *dbname, dbFILE *f)
     for (i = 0; i < tmp16; i++) {
 	int32 tmp32;
 	if (i < count) {  /* watch out for # of entries > MAX_MASKDATA */
-	    list[i].next = (MaskData *) i;
+	    list[i].next = (MaskData *) (long)i;
 	    SAFE(read_string(&list[i].mask, f));
 	    if (type == MD_EXCEPTION) {
 		SAFE(read_int16(&list[i].limit, f));
