@@ -1,6 +1,6 @@
 /* Main HTTP server module.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -331,7 +331,7 @@ static void do_readline(Socket *socket, void *param_unused)
 static void do_readdata(Socket *socket, void *param)
 {
     Client *c = find_client(socket);
-    int32 available = (int32)param, needed, nread;
+    int32 available = (int32)(long)param, needed, nread;
 
     if (!c) {
 	module_log("BUG: unexpected readdata callback for socket %p", socket);
