@@ -1,6 +1,6 @@
 /* Main NickServ module.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -430,6 +430,8 @@ static void do_help(User *u)
     } else if (stricmp(cmd, "RELEASE") == 0) {
 	notice_help(s_NickServ, u, NICK_HELP_RELEASE,
 		    maketime(u->ngi,NSReleaseTimeout,MT_SECONDS));
+    } else if (stricmp(cmd, "SUSPEND") == 0 && is_oper(u)) {
+	notice_help(s_NickServ, u, NICK_OPER_HELP_SUSPEND, s_OperServ);
     } else {
 	help_cmd(s_NickServ, u, module, cmd);
     }
@@ -1806,9 +1808,6 @@ static int do_reconfigure(int after_configure)
 
 int init_module(Module *module_)
 {
-    Command *cmd;
-
-
     module = module_;
 
     handle_config();
@@ -1851,10 +1850,6 @@ int init_module(Module *module_)
     if (!EnableGetpass)
 	cmd_GETPASS->name = "";
 
-    cmd = lookup_cmd(module, "SUSPEND");
-    if (cmd)
-	cmd->help_param1 = s_OperServ;
-
     cb_command       = register_callback(module, "command");
     cb_help          = register_callback(module, "HELP");
     cb_help_cmds     = register_callback(module, "HELP COMMANDS");
