@@ -1,6 +1,6 @@
 /* Autokill list module.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -406,6 +406,9 @@ static void do_akillchan(User *u)
     if (expiry)
 	expiry += time(NULL);
 
+    if (WallOSAkill)
+	wallops(s_OperServ, "%s used AKILLCHAN for \2%s\2", u->nick, c->name);
+
     count = 0;
     old_immed = ImmediatelySendAutokill;
     ImmediatelySendAutokill = 1;
