@@ -1,6 +1,6 @@
 /* Main OperServ module.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -323,7 +323,8 @@ static int do_save_data(void)
 static int do_reglink_check(const User *u, const char *nick,
 			    const char *pass, const char *email)
 {
-    return irc_stricmp(nick, s_OperServ) == 0;
+    return irc_stricmp(nick, s_OperServ) == 0
+	|| irc_stricmp(nick, s_GlobalNoticer) == 0;
 }
 
 /*************************************************************************/
@@ -1429,8 +1430,9 @@ static void send_user_list(User *user)
 	    snprintf(buf, sizeof(buf), "%04X", u->ni->status & 0xFFFF);
 	else
 	    strcpy(buf, "-");
-	notice(s_OperServ, source, "%s!%s@%s %s +%s %ld %u %s %s :%s",
+	notice(s_OperServ, source, "%s!%s@%s %s %s +%s %ld %u %s %s :%s",
 	       u->nick, u->username, u->host, u->fakehost ? u->fakehost : "-",
+	       u->ipaddr ? u->ipaddr : "-",
 	       mode_flags_to_string(u->mode, MODE_USER), (long)u->signon,
 	       u->servicestamp, u->server->name, buf, u->realname);
     }
@@ -1459,10 +1461,11 @@ static void send_user_info(User *user)
 	snprintf(buf, sizeof(buf), "%04X", u->ni->status & 0xFFFF);
     else
 	strcpy(buf, "-");
-    notice(s_OperServ, source, "%s!%s@%s %s +%s %ld %u %s %s :%s",
+    notice(s_OperServ, source, "%s!%s@%s %s %s +%s %ld %u %s %s :%s",
 	   u->nick, u->username, u->host, u->fakehost ? u->fakehost : "-",
-	   mode_flags_to_string(u->mode, MODE_USER), (long)u->signon,
-	   u->servicestamp, u->server->name, buf, u->realname);
+	   u->ipaddr, mode_flags_to_string(u->mode, MODE_USER),
+	   (long)u->signon, u->servicestamp, u->server->name, buf,
+	   u->realname);
     buf[0] = 0;
     s = buf;
     LIST_FOREACH (c, u->chans)
