@@ -1,6 +1,6 @@
 /* Bahamut protocol module for IRC Services.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -347,6 +347,41 @@ static void no_serviceshub(char *source, int ac, char **av)
 
 /*************************************************************************/
 
+/* SQUIT handler, for remote SQUITs.  This has to be implemented as a
+ * "receive message" callback because we can't layer message functions on
+ * top of each other. */
+
+static void do_bahamut_squit(char *source, int ac, char **av)
+{
+    Server *server;
+
+    if (ac < 1)  /* also checked in do_receive_message, but for completeness */
+	return;
+    server = get_server(av[0]);
+    if (!server) {
+	send_cmd(ServerName, "402 %s %s :No such server", source, av[0]);
+    } else if (!server->fake || server == get_server(ServerName)) {
+	/* We should never see an SQUIT for ourselves, since the remote
+	 * server will disconnect us instead, but just in case... */
+	send_cmd(ServerName, "402 %s %s :Not a juped server", source, av[0]);
+    } else {
+	do_squit(source, ac, av);
+	send_cmd(NULL, "SQUIT %s :%s", av[0], av[1] ? av[1] : "");
+    }
+}
+
+static int do_receive_message(char *source, char *cmd, int ac, char **av)
+{
+    if (irc_stricmp(cmd,"SQUIT") != 0)
+	return 0;
+    if (!source || !*source || ac < 1 || irc_stricmp(source,av[0]) == 0)
+	return 0;
+    do_bahamut_squit(source, ac, av);
+    return 1;
+}
+
+/*************************************************************************/
+
 static Message bahamut_messages[] = {
     { "AKILL",     NULL },
     { "CAPAB",     m_capab },
@@ -417,8 +452,6 @@ static void do_send_namechange(const char *nick, const char *newname)
 static void do_send_server(void)
 {
     send_cmd(NULL, "PASS %s :TS", RemotePassword);
-    /* Note that we don't actually support UNCONNECT (remote SQUITs) but
-     * Bahamut will throw us off if we don't claim to */
     send_cmd(NULL, "CAPAB TS3 SSJOIN NICKIP NOQUIT TSMODE UNCONNECT");
     send_cmd(NULL, "SERVER %s 1 :%s", ServerName, ServerDesc);
     send_cmd(NULL, "SVINFO 3 3 0 :%ld", (long)time(NULL));
@@ -719,7 +752,7 @@ static int do_cancel_akill(const char *username, const char *host)
 static int do_send_sgline(const char *mask, time_t expires, const char *who,
 			  const char *reason)
 {
-    send_cmd(ServerName, "SGLINE %d :%s:%s", strlen(mask), mask, reason);
+    send_cmd(ServerName, "SGLINE %d :%s:%s", (int)strlen(mask), mask, reason);
     return 1;
 }
 
@@ -853,6 +886,7 @@ int init_module(Module *module_)
 
     if (!add_callback(NULL, "load module", do_load_module)
      || !add_callback(NULL, "unload module", do_unload_module)
+     || !add_callback(NULL, "receive message", do_receive_message)
      || !add_callback(NULL, "user servicestamp change",
 		      do_user_servicestamp_change)
      || !add_callback(NULL, "channel MODE", do_channel_mode)
@@ -918,6 +952,7 @@ int exit_module(int shutdown)
     remove_callback(NULL, "channel MODE", do_channel_mode);
     remove_callback(NULL, "user servicestamp change",
 		    do_user_servicestamp_change);
+    remove_callback(NULL, "receive message", do_receive_message);
     remove_callback(NULL, "unload module", do_unload_module);
     remove_callback(NULL, "load module", do_load_module);
     unregister_messages(bahamut_messages);
