@@ -1,7 +1,7 @@
 /* trircd protocol module for IRC Services.
  * Provided by Yusuf Iskenderoglu <uhc0@stud.uni-karlsruhe.de>
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -1043,7 +1043,7 @@ static int do_cancel_exclude(const char *username, const char *host)
 static int do_send_sgline(const char *mask, time_t expires, const char *who,
 			  const char *reason)
 {
-    send_cmd(ServerName, "SGLINE %d :%s:%s", strlen(mask), mask, reason);
+    send_cmd(ServerName, "SGLINE %d :%s:%s", (int)strlen(mask), mask, reason);
     return 1;
 }
 
