@@ -1,6 +1,6 @@
 /* Unreal protocol module for IRC Services.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -620,6 +620,7 @@ static Message unreal_messages[] = {
     { "NICK",      m_nick },
     { "PROTOCTL",  m_protoctl },
     { "RAKILL",    NULL },
+    { "SENDSNO",   NULL },
     { "SETHOST",   m_sethost },
     { "SETIDENT",  m_setident },
     { "SETNAME",   m_setname },
@@ -629,6 +630,7 @@ static Message unreal_messages[] = {
     { "SQLINE",	   NULL },
     { "SVSMODE",   m_svsmode },
     { "SVS2MODE",  m_svsmode },
+    { "SWHOIS",	   NULL },
     { "TKL",       m_tkl },
     { "UMODE2",    m_umode2 },
     { NULL }
@@ -794,8 +796,13 @@ static TokenInfo tokens[] = {
     { "BR", "SVSJOIN" },
     { "BS", "BOTSERV" },
     { "BT", "SVSPART" },
+
+    /* 0x45xx */
     { "ES", "EOS" },
 
+    /* 0x53xx */
+    { "Ss", "SENDSNO" },
+
     /* Fencepost */
     { NULL }
 };
@@ -1317,16 +1324,23 @@ static int do_check_kick(User *user, Channel *c, ChannelInfo *ci,
 /*************************************************************************/
 
 /*
- * ChanServ SET MLOCK callback; we handle locking modes +/-L and +/-f.
+ * ChanServ SET MLOCK callback; we handle locking modes f, K, and L.
  */
 
 static int do_set_mlock(User *u, ChannelInfo *ci, int mode, int add, char **av)
 {
     if (!mode) {
 	/* Final check of new mode lock */
+	if ((ci->mlock_on & mode_char_to_flag('K',MODE_CHANNEL))
+	 && !(ci->mlock_on & CMODE_i)
+	) {
+	    /* +K requires +i */
+	    notice_lang(s_ChanServ, u, CHAN_SET_MLOCK_REQUIRES, 'K', 'i');
+	    return 1;
+	}
 	if (ci->mlock_link && !ci->mlock_limit) {
 	    /* +L requires +l */
-	    notice_lang(s_ChanServ, u, CHAN_SET_MLOCK_LINK_NO_LIMIT, 'L');
+	    notice_lang(s_ChanServ, u, CHAN_SET_MLOCK_REQUIRES, 'L', 'l');
 	    return 1;
 	}
 	return 0;
@@ -1486,6 +1500,25 @@ static int do_cancel_exclude(const char *username, const char *host)
  * protocols.
  */
 
+static int do_send_sgline(const char *mask, time_t expires, const char *who,
+			  const char *reason)
+{
+    char buf[BUFSIZE], *s;
+
+    s = buf;
+    while (*reason && s-buf < sizeof(buf)-1) {
+	if (*reason == ' ')
+	    *s = '_';
+	else
+	    *s = *reason;
+	reason++;
+	s++;
+    }
+    *s = 0;
+    send_cmd(ServerName, "SVSNLINE + %s :%s", buf, mask);
+    return 1;
+}
+
 static int do_send_sqline(const char *mask, time_t expires, const char *who,
 			  const char *reason)
 {
@@ -1508,6 +1541,12 @@ static int do_send_szline(const char *mask, time_t expires, const char *who,
  * protocols.
  */
 
+static int do_cancel_sgline(const char *mask)
+{
+    send_cmd(ServerName, "SVSNLINE - :%s", mask);
+    return 1;
+}
+
 static int do_cancel_sqline(const char *mask)
 {
     send_cmd(ServerName, "UNSQLINE %s", mask);
@@ -1569,10 +1608,14 @@ static int do_load_module(Module *mod, const char *modname)
 		module_log("Unable to add cancel_exclude callback");
 	}
     } else if (strcmp(modname, "operserv/sline") == 0) {
+	if (!add_callback(mod, "send_sgline", do_send_sgline))
+	    module_log("Unable to add send_sgline callback");
 	if (!add_callback(mod, "send_sqline", do_send_sqline))
 	    module_log("Unable to add send_sqline callback");
 	if (!add_callback(mod, "send_szline", do_send_szline))
 	    module_log("Unable to add send_szline callback");
+	if (!add_callback(mod, "cancel_sgline", do_cancel_sgline))
+	    module_log("Unable to add cancel_sgline callback");
 	if (!add_callback(mod, "cancel_sqline", do_cancel_sqline))
 	    module_log("Unable to add cancel_sqline callback");
 	if (!add_callback(mod, "cancel_szline", do_cancel_szline))
