@@ -2,7 +2,7 @@
  * Based on code (c) Andrew Kempe (TheShadow)
  *     E-mail: <andrewk@isdial.net>
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -584,6 +584,9 @@ static int do_reconfigure(int after_configure)
 
 int init_module(Module *module_)
 {
+    Module *tmpmod;
+
+
     module = module_;
 
     if (!new_commandlist(module) || !register_commands(module, cmds)) {
@@ -619,6 +622,10 @@ int init_module(Module *module_)
 	return 0;
     }
 
+    tmpmod = find_module("nickserv/main");
+    if (tmpmod)
+	do_load_module(tmpmod, "nickserv/main");
+
     if (!open_statserv_db(StatDBName)) {
 	module_log("Unable to read database");
 	exit_module(0);
