@@ -1,6 +1,6 @@
 /* Socket routines.
  *
- * IRC Services is copyright (c) 1996-2004 Andrew Church.
+ * IRC Services is copyright (c) 1996-2005 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -476,6 +476,16 @@ void check_sockets(void)
 		continue;
 	    }
 	    /* Normal read */
+	    if (read_buffer_len(s) >= s->rbufsize-1) {
+		/* Buffer is full, try to expand it */
+		int newsize = 0;
+		if (s->rbufsize < NET_MIN_BUFSIZE)
+		    newsize = NET_MIN_BUFSIZE;
+		else if (s->rbufsize+NET_MIN_BUFSIZE < NetBufferSize)
+		    newsize = s->rbufsize + NET_MIN_BUFSIZE;
+		if (newsize > 0)
+		    resize_rbuf(s, newsize);
+	    }
 	    res = fill_read_buffer(s);
 	    if (res < 0) {
 		/* Connection was closed (or some other error occurred) */
@@ -497,7 +507,7 @@ void check_sockets(void)
 		do {
 		    newleft = left;
 		    if (s->cb_read) {
-			s->cb_read(s, (void *)newleft);
+			s->cb_read(s, (void *)(long)newleft);
 			if ((s->flags & SF_DISCONNECT) || s->fd < 0)
 			    break;
 			newleft = read_buffer_len(s);
@@ -513,7 +523,7 @@ void check_sockets(void)
 						 s->rend - s->rbuf);
 			}
 			if (newline) {
-			    s->cb_readline(s, (void *)newleft);
+			    s->cb_readline(s, (void *)(long)newleft);
 			    if ((s->flags & SF_DISCONNECT) || s->fd < 0)
 				break;
 			    newleft = read_buffer_len(s);
@@ -558,6 +568,10 @@ void check_sockets(void)
  * If either host or lhost is not a valid IP address and the gethostbyname()
  * function is available, this function may block while the hostname is
  * being resolved.
+ *
+ * This function may be called from a socket's disconnect callback to
+ * establish a new connection using the same socket.  It may not be called,
+ * however, if the socket is being freed with sock_free().
  */
 
 int conn(Socket *s, const char *host, int port, const char *lhost, int lport)
@@ -577,6 +591,11 @@ int conn(Socket *s, const char *host, int port, const char *lhost, int lport)
 	errno = EINVAL;
 	return -1;
     }
+    if (s->flags & SF_DELETEME) {
+	log("sockets: conn() called on a freeing socket (%p)", s);
+	errno = EPERM;
+	return -1;
+    }
     memset(&lsa, 0, sizeof(lsa));
     lsa.sin_family = AF_INET;
     if (lhost) {
@@ -1120,7 +1139,12 @@ static int fill_read_buffer(Socket *s)
 	if (s->rend == s->rtop)
 	    s->rend = s->rbuf;
     }
-    errno = errno_save;
+    if (nread == 0) {
+	nread = -1;
+	errno = ENOBUFS;
+    } else {
+	errno = errno_save;
+    }
     return nread;
 }
 
@@ -1407,9 +1431,9 @@ static int do_disconn(Socket *s, void *code)
     if (s == NULL || (s->flags & SF_LISTENER)) {
 	if (s)
 	    log("sockets: do_disconn(%d) with listener socket (%d)!",
-		(int)code, s->fd);
+		(int)(long)code, s->fd);
 	else
-	    log("sockets: do_disconn(%d) with NULL socket!", (int)code);
+	    log("sockets: do_disconn(%d) with NULL socket!", (int)(long)code);
 	errno = EINVAL;
 	return -1;
     }
@@ -1429,13 +1453,18 @@ static int do_disconn(Socket *s, void *code)
 	    return 0;
 	}
     }
+    shutdown(s->fd, 2);
+    sock_closefd(s);
     s->flags |= SF_DISCONN_CB;
     if (s->cb_disconn) {
 	errno = errno_save;
 	s->cb_disconn(s, code);
     }
-    shutdown(s->fd, 2);
-    sock_closefd(s);
+    if (s->fd >= 0) {
+	/* The socket was reconnected */
+	s->flags &= ~SF_DISCONN_CB;
+	return 0;
+    }
     s->flags &= ~(SF_CONNECTING | SF_CONNECTED | SF_DISCONN_CB);
     if (s->flags & (SF_SELFCREATED | SF_DELETEME)) {
 	if (s->flags & SF_CALLBACK)
